# - Config file for the Dakota package
# It defines the following variables
#  Dakota_INCLUDE_DIRS - include directories for Dakota
#  Dakota_LIBRARIES    - libraries to link against
#  Dakota_EXECUTABLE   - the dakota executable

# Compute paths
get_filename_component(DAKOTA_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

# Check existence since may be building/installing under
# Trilinos/TriKota, or using an external Trilinos
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
endif()

# Conservative approach for now
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
  set(Eigen3_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
endif()
include(CMakeFindDependencyMacro)
find_dependency(Eigen3)

# Our library dependencies (contains definitions for IMPORTED targets)
include("${DAKOTA_CMAKE_DIR}/DakotaTargets.cmake")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DakotaConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Build tree option not yet working
if (Dakota_BUILD_TREE)
  # Dakota's build tree doesn't have a single convenient place for headers
  set(Dakota_INCLUDE_DIRS_TMP "/wrkdirs/usr/ports/science/dakota/work/.build/generated/src;/wrkdirs/usr/ports/science/dakota/work/.build;/wrkdirs/usr/ports/science/dakota/work/.build/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/remainder/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/remainder/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/core/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/core/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/numerics/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/comm/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/parameterlist/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/parser/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/pecos;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/pecos/util/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/pecos/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/VPISparseGrid/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/surfpack;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/surfpack/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/src/util;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/src/surrogates;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/eigen3/include/eigen3;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/acro/packages;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/acro/packages/utilib;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/interfaces/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/scolib/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/utilib/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/colin/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/pebbl/src/bb;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/pebbl/src/comm;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/pebbl/src/misc;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/pebbl/src/pbb;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/packages/pebbl/src/sched;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/acro/tpl/tinyxml;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/approxnn/include;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/queso/include/;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/DDACE;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/DDACE/include;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/dream;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/FSUDace;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/FSUDace;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/hopspack/src/src-shared;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/hopspack/src/src-shared;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/hopspack/src/src-citizens;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/hopspack/src/src-evaluator;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/hopspack/src/src-executor;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/hopspack/src/src-framework;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/hopspack/src/src-main;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/JEGA;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/JEGA/eddy;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/JEGA/eddy;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/JEGA/include;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/NOMAD/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/NOMAD/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/OPTPP/include;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/OPTPP/include;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/muq2/include;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/rol/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/rcp;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/parameterlist;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/stacktrace;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/la;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/lapack;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/blas;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/vector;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/dynamic;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/boundconstraint;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/constraint;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/nlls;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/objective;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/operator;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/simopt;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/sketching;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/function/std;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/linesearch;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/trustregion;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/secant;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/krylov;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/bundle;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/augmentedlagrangian;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/moreauyosidapenalty;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/interiorpoint;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/nonlinearcg;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/step/fletcher;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/algorithm;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/status;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/distribution;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/expectationquad;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/fdivergence;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/spectral;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/error;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/regret;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/deviation;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/probability;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/progressivehedging;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/algorithm;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/algorithm/PrimalDual;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/vector;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/sampler;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/sampler/SROM;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/sol/status;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/elementwise;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/utils;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/utils/function_bindings;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/zoo;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/rol/src/zoo/testproblems;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/remainder/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/remainder/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/core/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/core/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/numerics/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/comm/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/parameterlist/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/trilinos/packages/teuchos/parser/src;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/PSUADE;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/src/graphics;/wrkdirs/usr/ports/science/dakota/work/dakota-6.17.0-release-public-src-cli/packages/external/sciplot;/usr/local/include;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/ampl")
  # This won't work yet.  Since Dakota is in a build tree the
  # libraries are scattered, but the import doesn't know where they
  # are.
  set(Dakota_LIBRARY_DIRS_TMP "/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/remainder/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/core/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/numerics/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/comm/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/parameterlist/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/trilinos/packages/teuchos/parser/src;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/muq2/lib;/wrkdirs/usr/ports/science/dakota/work/.build/packages/external/sciplot")
else()
  set_and_check(Dakota_INCLUDE_DIRS_TMP "${PACKAGE_PREFIX_DIR}/include")
  set_and_check(Dakota_LIB_DIRS_TMP "${PACKAGE_PREFIX_DIR}/lib")
endif()

# Variables intended for use by other projects

set_and_check(Dakota_DIR ${DAKOTA_CMAKE_DIR})

# TODO: reference in src vs bin
set(Dakota_EXECUTABLE dakota)


set(Dakota_DEFINES "HAVE_CONFIG_H;HAVE_DAKOTA_SURROGATES;HAVE_CONFIG_H;DISABLE_DAKOTA_CONFIG_H;BOOST_DISABLE_ASSERTS;HAVE_UNISTD_H;HAVE_SYSTEM;HAVE_WORKING_FORK;HAVE_WORKING_VFORK;HAVE_SYS_WAIT_H;DAKOTA_HAVE_HDF5;HAVE_;HAVE_SURFPACK;HAVE_DAKOTA_SURROGATES;DAKOTA_F90;HAVE_ACRO;DAKOTA_UTILIB;HAVE_APPROXNN;HAVE_ADAPTIVE_SAMPLING;HAVE_QUESO;HAVE_QUESO_GPMSA;HAVE_CONMIN;HAVE_DDACE;HAVE_DREAM;HAVE_FSUDACE;DAKOTA_HOPS;HAVE_JEGA;HAVE_NCSU;HAVE_NL2SOL;HAVE_NOMAD;HAVE_OPTPP;DAKOTA_OPTPP;HAVE_MUQ;HAVE_ROL;HAVE_PSUADE;HAVE_X_GRAPHICS;HAVE_AMPL")

set(Dakota_INCLUDE_DIRS ${Dakota_INCLUDE_DIRS_TMP})

set(Dakota_LIBRARY_DIRS ${Dakota_LIB_DIRS_TMP})

# These are IMPORTED targets created by DakotaTargets.cmake
set(Dakota_LIBRARIES "dakota_surrogates;dakota_util;dakota_src;dakota_src_fortran;nidr;teuchosremainder;teuchosnumerics;teuchoscomm;teuchosparameterlist;teuchosparser;teuchoscore;pecos_util;pecos_src;lhs;lhs_mods;lhs_mod;dfftpack;sparsegrid;surfpack;surfpack;surfpack_fortran;utilib;colin;interfaces;scolib;3po;pebbl;tinyxml;approxnn;queso;conmin;ddace;dream;fsudace;hopspack;jega;jega_fe;moga;soga;eutils;utilities;ncsuopt;cport;nomad;optpp;muqUtilities;muqModeling;muqSamplingAlgorithms;psuade;dakota_sciplot;amplsolver")

# Not built in Dakota's CMake process
set(Dakota_EXTPROJ_LIBRARIES "")

# TPLs external to the build
set(Dakota_TPL_INCLUDE_DIRS "/usr/local/include;/usr/local/include")

set(Dakota_TPL_LIBRARY_DIRS "")

set(Dakota_TPL_LIBRARIES "hdf5_hl-shared;hdf5_hl_cpp-shared;hdf5-shared;hdf5_cpp-shared;/usr/local/lib/libXm.so;/usr/local/lib/libXmu.so;/usr/local/lib/libXt.so;/usr/local/lib/libXext.so;/usr/local/lib/libXpm.so;/usr/local/lib/libXrender.so;/usr/local/lib/libX11.so;/usr/local/lib/libXft.so;/usr/local/lib/libSM.so;/usr/local/lib/libICE.so;/usr/local/lib/libXau.so;/usr/local/lib/libXdmcp.so;/usr/local/lib/libSM.so;/usr/local/lib/libICE.so;/usr/local/lib/libX11.so;/usr/local/lib/libXext.so;-lpthread;/usr/local/lib/libgsl.so;/usr/local/lib/libgslcblas.so;/usr/local/lib/liblapack.so;/usr/local/lib/libblas.so")
